@@ -16,15 +16,7 @@ class TQDMDaskProgressBar(Callback, object):
     See: http://dask.pydata.org/en/latest/diagnostics-local.html?highlight=progress
     """
 
-    def __init__(
-        self,
-        start=None,
-        start_state=None,
-        pretask=None,
-        posttask=None,
-        finish=None,
-        **kwargs
-    ):
+    def __init__(self, start=None, start_state=None, pretask=None, posttask=None, finish=None, **kwargs):
         super(TQDMDaskProgressBar, self).__init__(
             start=start,
             start_state=start_state,
@@ -36,9 +28,7 @@ class TQDMDaskProgressBar(Callback, object):
         self.states = ["ready", "waiting", "running", "finished"]
 
     def _start_state(self, dsk, state):
-        self._tqdm = tqdm(
-            total=sum(len(state[k]) for k in self.states), **self.tqdm_args
-        )
+        self._tqdm = tqdm(total=sum(len(state[k]) for k in self.states), **self.tqdm_args)
 
     def _posttask(self, key, result, dsk, state, worker_id):
         self._tqdm.update(1)
